#
# spec file for package vifm
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vifm
Version:        0.14.3
Release:        1.1
Summary:        Ncurses based file manager with vi like keybindings
License:        GPL-2.0-or-later
Group:          Productivity/File utilities
URL:            http://%{name}.info
Source0:        https://github.com/vifm/vifm/releases/download/v%{version}/%{name}-%{version}.tar.bz2
Source1:        https://github.com/vifm/vifm/releases/download/v%{version}/%{name}-%{version}.tar.bz2.asc
Source2:        %{name}.keyring
BuildRequires:  file-devel
BuildRequires:  glib2-devel
BuildRequires:  groff
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif
%if 0%{?suse_version} > 1110
BuildRequires:  pkgconfig(x11)
%else
BuildRequires:  xorg-x11-devel
%endif

%description
Vifm is a ncurses based file manager with vi like keybindings that allow complete
keyboard control over your files without having to learn a new set of commands.
It supports UTF-8, a quick file view similar to midnight commander's quick view,
and configurable color schemes.

%prep
%setup -q
sed -i 's/#!\/usr\/bin\/env perl/#!\/usr\/bin\/perl/' src/vifm-convert-dircolors

%build
%configure \
	--with-curses \
	--with-libmagic \
	--with-glib \
	--disable-developer
%make_build
gzip -9c ChangeLog > ChangeLog.gz

%install
make install DESTDIR="%{?buildroot}"
%if 0%{?suse_version}
%suse_update_desktop_file %{name}
%endif
rm -rf %{buildroot}%{_datadir}/doc/vifm/*
rm -rf %{buildroot}%{_datadir}/vifm/vifmrc-osx
rm -rf %{buildroot}%{_datadir}/vifm/vifm-media-osx
rm -rf %{buildroot}%{_datadir}/vifm/vim-doc/doc/tags
rm -rf %{buildroot}%{_datadir}/vifm/vim-doc/doc/vifm-app.txt

%files
%license COPYING
%doc AUTHORS BUGS ChangeLog.* README TODO
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/vim-doc
%dir %{_datadir}/%{name}/vim-doc/doc
%doc %{_datadir}/%{name}/%{name}-help.txt
%doc %{_datadir}/%{name}/vim-doc/doc/%{name}-lua.txt
%{_bindir}/*
%{_datadir}/%{name}/vim
%{_datadir}/%{name}/%{name}rc
%{_datadir}/%{name}/colors/
%{_datadir}/%{name}/vifm-media
%{_mandir}/man1/*
%{_datadir}/applications/*
%{_datadir}/pixmaps/*
%dir %{_datadir}/bash-completion/
%dir %{_datadir}/bash-completion/completions/
%{_datadir}/bash-completion/completions/vifm
%dir %{_datadir}/zsh/
%dir %{_datadir}/zsh/site-functions/
%{_datadir}/zsh/site-functions/_vifm
%dir %{_datadir}/fish/
%dir %{_datadir}/fish/vendor_completions.d/
%{_datadir}/fish/vendor_completions.d/vifm.fish
%{_sysconfdir}/vifm/
%{_sysconfdir}/vifm/colors/
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/128x128
%dir %{_datadir}/icons/hicolor/128x128/apps
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/128x128/apps/vifm.png
%{_datadir}/icons/hicolor/scalable/apps/vifm.svg

%changelog
* Thu Jun  5 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.14.3:
  Documentation:
  * Improved documentation on the use of registers.
  Menus and dialogs:
  * Say primary instead of default in the title of :colorscheme menu.
  Other changes:
  * Provided more details on file handlers and viewers in sample vifmrc files.
  Fixes:
  * Fixed picking trash directory when rooted trash is included in 'trashdir'
    and root is writable.  Regression in v0.14.2 (unfortunately, testing this
    automatically is problematic).
  * Fixed unlimited growth of directory histories when 'history' is set to its
    default value or not set at all in vifmrc.
  * Fixed abort due to assertion on displaying a statusbar message with a
    newline when 'shortmess' includes T.
* Thu May  8 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.14.2:
  * Fix an issue with %%r in 'trashdir' when root file-system is
    read-only (like on macOS) and also broke build with musl libc.
  * Trash directories specified via an absolute path and containing
    %%u weren't created with 700 permissions.
  * Don't use strverscmp() of musl if it doesn't sort things
    correctly (A must be greater than 0).  This avoids numerical
    sorting results looking different with musl.
* Thu May  8 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.14.1:
  * Fixed a preview-related crash on Windows easily reproducible using binary files.
  * Fixed a tree-related crash when using {fileext} or {ext} columns.
  * Fixed 'trashdir' with %%r not working on BSD-like systems.
  * Fixed vifm path/to/file incorrectly running file handling in current working directory.
  * Restored terminal access for commands that use %%i macro (so :!echo ... %%i can affect the
    terminal as before v0.12.1). Use %%i & for ignoring output while denying terminal accesses.
  * Fixed occasional incorrect truncation of wide characters on drawing columns broken while
    introducing column-specific highlighting in v0.14-beta.
  * Clarified information on comments after :commands. Provided some information on copy-on-write
    file copying. Improved documentation on leaving compare and custom views.
* Mon Feb 10 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.14:
  * Somewhat incompatible changes
    This release contains a number of changes which are technically non-backwards
    compatible. However, all of them should have very little negative impact (i.e.,
    hard to notice the change without reading the changelog).
    At the same time, a bug, fixing which is likely to have an impact on user
    configuration, has been identified but not yet fixed to give a chance to
    update all affected vifmrc files. If a bug is likely to be relied on by the
    configuration, a dialog with the explanation and instructions will appear.
  * Sorting and non-Latin characters
    Until this release Vifm has always used byte sorting (effectively, sorting
    of UTF-8 byte sequences). From now on a form of Unicode normalization is
    applied to strings when sorting views and completion results. The change
    can be expanded to other cases in future releases. The measured performance
    impact is negligible (several percent).
    Practically, this means that characters like a and ä are now grouped
    together regardless of the way in which diacritic is being encoded. Some
    characters can still appear in weird non-alphabetic positions because full
    Unicode normalization results in losing case sensitivity and is therefore
    not applied.
  * Addressing some longtime woes
    For one reason or another some inconvenient peculiarities have accumulated
    over the years. Time has come to replace workarounds with something better:
    + global variables (g:var) replace the use of environmental variables
    for internal purposes, thus avoiding polluting environment of child processes
    + use of :let to invoke a builtin function discarding its result is
    superseded by a proper :call command
    + use of execute 'normal! gl' to run selection now has :open command
    as a better alternative
    + size of selection can now be queried via selected() (previous releases
    required expand('%%c') == expand('%%f') or an equivalent trick)
    + %%{expression} macro in 'statusline' can now have } embedded as \} (\\ still means two slashes)
    + dialogs now recognize Enter and Escape keys as "yes" and "no" replies
  * More useful menus
    :copen recalled last navigation menu for years, but that's not always
    enough. Now up to 25 such menus are stored after their use and can be
    navigated to via :chistory/:colder/:cnewer.
    In addition, :grep or :find can be rerun on the same set of commands right
    from the menu which previously required leaving the menu just to get back
    to it.
    History of command-line in menus is now also managed and stored, making
    staying in menu mode for longer a more pleasant experience.
  * UI improvements
    Navigation between views/tabs via new :wingo command with optional
    incremental completion thanks to new 'wildinc' option (applicable to any
    other command or all of them at once).
    Ability to highlight a view column (:highlight column:size ...), specify
    how highlighting applies ('hloptions'), set a separator between miller
    columns in set fillchars+=millersep:'|', shorten columns in the middle (^
    in 'viewcolumn').
    Also, displaying of CJK characters on Windows should have much fewer issues now.
  * Lua API
    Slowly adding new functionality. This batch comes with things like
    primitive file operations, ability to create custom views or menus and
    handling ranges of :commands.
  * Other
    Search matches can be traversed via Tab and Shift-Tab while in the prompt
    (applies to navigation mode as well).
    An invalid expression in :if or :elseif no longer just skips that command,
    now all commands up to and including matching :endif are skipped to avoid
    executing half-random sequences of commands due to a mistake, which also
    results in better error messages. Previously, :elseif was also evaluating
    its expression even some earlier branch was already taken.
    :rename now asks whether file move is intended instead of assuming a user
    mistake and refusing to proceed.
    Support MTP devices by bundled vifm-media script if simple-mtpfs is
    installed. Also improve what devices are offered for mounting (e.g., don't
    offer a whole drive if it contains partitions).
    v:version to branch depending on release.
  * Fixes
    Get preview graphics out of the way in more cases (like when opening
    menus). Terminals with more than 32768 color pairs should not cause visual
    defects or crashes anymore.
    Merging of directories was either not asking for confirmation or aborting
    after skipping a file. Paths with some unreadable characters were not
    processed due to a regression. Directories weren't counted in estimates of
    file operations.
    && operator was always evaluating both branches instead of properly
    short-circuiting. %%a macro of 'statusline' was displaying wrong values on
    non-Linux Unix-like systems. :compare falsely claimed that files of
    identical size and with common prefix are identical.
* Thu Apr  6 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.13:
  * Faster file-system navigation with new searching/filtering
    submodule
  * More interactive :compare
  * Mouse supports and TUI improvements
  * %%N macro has been adjusted to fix integration with image preview
    of Kitty v0.27+.
  * Lots of fixes related to search and various combinations of'
    hlsearch', 'incsearch' in different modes.
* Thu Sep 22 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.12.1:
  * Expression register for command-line prompts (Ctrl-R =)
  * Selection handling improvements
  * An arbitrary editor can now be fully integrated via Lua
  * TUI improvements
  * Lua API additions (still experimental)
  * Bulk retargetting of links, optional implicit :cd on command line,
    macros that expand to non-empty selection, supporting more <keys>,
    completion for fish shell.
  * Escaping of arguments and slashes in paths will now hopefully
    work better on Windows, which is generally an issue there. Yori
    shell is now also handled on Windows.
  * New %%N macro can be used to fix image preview in Kitty terminal.
  * For details see https://vifm.info/news/2022-09-21.shtml
* Thu Sep 30 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.12:
  * Color schemes and preview now support 24-bit colors.
  * Depth of tree-view can now be limited and directories in it
    can be folded.
  * Textual preview of files is now done asynchronously.
  * List of files can now be directly piped to programs via new macros.
  * External editing now asks for a re-edit after a failure.
  * Status line can now take up several lines.
  * New keys for controlling viewer while in view mode.
  * View column separators.
  * Vifm has received a more advanced, but currently experimental,
    extension interface in a form of Lua plugins.
  * New logo.
  * See https://vifm.info/news/2021-09-29.shtml for details
* Thu Sep 24 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.11:
  * Added persistent tabs
  * Added sessions
  * New format of vifminfo file (old version is imported on first run)
  * Smarter merging of histories between runs that avoids dropping of new entries
  * Version of default color scheme for 256-color terminals
  * Customizable tab labels
  * Keeping ratio of pane sizes constant on resizes, restarts and tab switching
  * Various performance improvements
  * See change log for the full list of changes and by whom they were suggested.
* Tue Jul 30 2019 mvetter@suse.com
- Update to 0.10.1:
  * Added file preview to miller mode
  * Added preview macro to directly output to terminal, which
    enables use of Sixel graphics for previewing
  * Added udisks2 backend to vifm-media script (bundled script for
    managing media) and version of the script for OS X
  * Updated code to make use of large amount of color pairs when
    available
  * Functionality of previously separate neovim-vifm plugin got
    merged into the main plugin
  * Multiple improvements to :media menu
  * Improved performance in several use cases (quickview, lots
    of unhighlighted files, unnecessary cursor updates and redraws)
  * See change log for the full list of changes and by whom
    they were suggested.
* Mon Nov 12 2018 mvetter@suse.com
- Update to 0.10:
  * New version includes long awaited tabs and support for managing media.
    The first one comes in two flavours: tabs either include layout or don't.
    The latter relies on a helper script, whose job is to adapt existing
    tools to make them usable by vifm.
  Main changes:
  * Added tabs which either operate on the level of layout or level of individual panes
  * Added ability to synchronize contents of registers among multiple instances
  * Added menu for managing media (relies on helper that does the managing)
  * Improved cursor positioning and control over it
  * Ability to colorize statusline
- For more details see: https://vifm.info/news/2018-11-11.shtml
- Update upstream gpg key file (xaizek@posteo.net)
* Mon Feb  5 2018 mvetter@suse.com
- Update to 0.9.1:
  * Introduced file view mode known as miller columns or cascading lists, which can be enabled via 'millerview' and configured with 'milleroptions'.
  * Added ability to transpose ls-like view to make it fill by columns, see new 'lsoptions' option.
  * More natural behaviour of movement keys in ls-like view.
  * New --remote-expr command-line option that can be used to query state of running instances.
  * Extended retry/ignore/abort query of 'syscalls' to all file operations.
  * More control over highlight groups via :highlight suitable for interactive changes.
  * Mostly eliminated the need for repeating ga/gA command through automatic size recalculation.
* Sun Jun 18 2017 mvetter@suse.com
- Add vifm.asc
- Add xaizek@openmailbox.org 's 0x99dc5e4db05f6be2 to keyring
* Sun Jun 18 2017 mvetter@suse.com
- Update to 0.9:
  * New version brings two new ways of viewing and processing file lists, namely tree-view and directory-comparison. As usual, previously existing facilities were extended and improved to become more useful.
  * Introduced tree-like representation of files.
  * Added directory comparison facilities.
  * Added ability to restore last navigation menu.
  * Background operations and programs can now be cancelled.
  * Dismissed error output of external programs can now be queried.
  * Added shell completion for bash and zsh.
  * Now it's possible to configure mappings in dialogs.
* Sun Jun  4 2017 mvetter@suse.com
- update to 0.9 beta:
  * Introduced tree-like representation of files.
  * Added directory comparison facilities.
  * Added ability to restore last navigation menu.
  * Background operations and programs can now be cancelled.
  * Dismissed error output of external programs can now be queried.
  * Added shell completion for bash and zsh.
  * Now it's possible to configure mappings in dialogs.
- Install bash and zsh completion files
* Sat Jul 16 2016 mvetter@suse.com
- Update to version 0.8.2:
  * key suggestions in the interface on ambiguous input (e.g. "g");
  * helpful shortcuts for dialogs (for sort dialog in particular);
  * key descriptions in :map menus and %%z macro for 'statusline' to display some tips;
  * description of all :commands, 'options' and their values for new multiline
  version of wildmenu;
  * ANDing, ORing and negating patterns for matching files and new mime-type
  matcher;
  * file prefixes and suffixes can now be multi-byte, which with extended
  'classify' option allows specifying "icons" via custom fonts;
  * search result highlighting, enabled completion and a way to export the list
  for menus;
  * an indication of pattern correctness and match state for interactive prompts.
  * :select and :unselect commands to perform automatic file selection (possibly
  by using output of external application);
  * cancellation (handling of Ctrl-C) for quick view and view mode loading.
* Sat Jul  2 2016 mvetter@suse.com
- Update to version 0.8.2 Beta 1:
  * Key suggestions in the interface on ambiguous input (e.g. g).
  * Helpful shortcuts for dialogs (for sort dialog in particular).
  * Key descriptions in :map menus and %%z macro for 'statusline' to display some tips.
  * Description of all :commands, 'options' and their values for new multiline version of wildmenu.
  * ANDing, ORing and negating patterns for matching files and new mime-type matcher.
  * File prefixes and suffixes can now be multi-byte, which with extended 'classify' option allows specifying "icons" via custom fonts.
  * Search result highlighting, enabled completion and a way to export the list for menus.
  * An indication of pattern correctness and match state for interactive prompts.
  * :select and :unselect commands to perform automatic file selection (possibly by using output of external application).
  * Cancellation (handling of Ctrl-C) for quick view and view mode loading.
  * For the complete list see: https://vifm.info/news/2016-07-02.shtml
* Thu Feb 11 2016 mvetter@suse.com
- Update to version 0.8.1a
  This is a bugfix release to primarily address messed up single-executable builds for Windows.
  Other bugfixes:
  * Fixed storing filetypes in vifminfo, which could create duplicates.
  * Fixed --with-dyn-x11 configuration option, which failed to enable dynamic use of the library.
  * Fixed using plugin in neovim, which has broken system() and :! commands.
* Sun Jan 17 2016 mvetter@suse.com
- Update to version 0.8.1
  * Added local options, which work until directory change.
  * Added named bookmarks (paths are associated with tags).
  * Added autocommands (with DirEnter event).
  * Added ability to sort by regexp-extracted part of file name.
  * Added builtin directory preview (similar to tree).
  * Added a way to communicate menu contents to Vim quickfix.
  * Added "more" mode that is used to handle status bar content that doesn't fit on the screen.
  * IPC got new (safe) implementation with listing/targeting of active instances, it's enabled by default again.
  * Updating local view settings from vifmrc now affects both panes (:windo is not necessary).
  * More predictive cursor updates on directory reload.
  * Improvements related to expression and command parsing.
- Remove vifm_utils_nix_dynamic_page_size_for_powerpc.patch:
  Got upstreamed
* Thu Aug 27 2015 normand@linux.vnet.ibm.com
- new patch to avoid build failure for PowerPC architectures
  vifm_utils_nix_dynamic_page_size_for_powerpc.patch
* Fri Jul 10 2015 mvetter@suse.com
- Update to version 0.8
  * Added filename specific highlight (with a script to convert ls options).
  * Added custom views, which contrary to regular views can contain files that do not belong to the same directory.
  * Added job bar to display active backgrounded file operations.
  * Added command-line mode abbreviations.
  * Added global configuration and color schemes directory.
  * Added live search match highlighting.
  * Added optional per-file progress for file operations.
  * Added full path patterns ({{globs}} and //regexp//).
  * Added command-line options to control file/directory selection and selection processing to make it easier to use vifm as a file picker.
  * Color schemes got ".vifm" extension, but the old-style names will still work for now.
  * XDG specification support.
  * Ability to use terminal applications to preview graphics (e.g. w3mimgdisplay).
* Wed Apr  8 2015 g.bluehut@gmail.com
- Update projects website URL
* Tue Apr  7 2015 g.bluehut@gmail.com
- Use suse_update_desktop_file only when on suse.
- Ran spec-cleaner
* Tue Apr  7 2015 g.bluehut@gmail.com
- Add BuildRoot
* Thu Apr  2 2015 g.bluehut@gmail.com
- Dont use the make_install macro so it works for older systems too
* Thu Apr  2 2015 g.bluehut@gmail.com
- Use pkgconfig(x11) instead libX11-devel so it is adaptable to name changes
- In case of versions older or equal to 1110 we have to use the old xorg-x11-devel package
* Thu Apr  2 2015 g.bluehut@gmail.com
- Use libX11-devel instead of xorg-x11-devel meta package as dependency
* Thu Apr  2 2015 g.bluehut@gmail.com
- Install the COPYING file too
* Wed Mar 25 2015 g.bluehut@gmail.com
- update from 0.7.6 to 0.7.8 include:
  - plenty of bugfixes, some important ones were:
  - fixed memory leaks on :restart
  - fixed segmentation fault for long argument lists
  - fixed possible removing files at destination on restoring files from trash manually
  - new color schemes:
  - zenburn
  - improved documentation
  - added several new commands:
  - gf
  - av
  - lstrash
  - include regular expression in search error message that says that it's wrong
  - added support for 256 colors with xterm-like names
  - added several new hilight groups
  - added "not-operator"
* Thu Oct 30 2014 Led <ledest@gmail.com> 0.7.8-1
- 0.7.8
- clean up spec
* Fri Jan  3 2014 pascal.bleser@opensuse.org
- update to 0.7.6:
  - added interactive local filter
  - added external editing of command-line content with 'vicmd'
  - added integration with tmux
  - added options to configure external commands for :apropos, :find, :grep
    and :locate commands
  - added desktop entry file (\*nix only) and updated application icon
- changes from 0.7.5:
  - removed using of libtool in build process on *nix-like systems
  - added parsing of escape codes for the preview pane and less-like view
  - added expand() builtin function
  - added macros that are expanded to register's content
  - added dynamic loading of xlib
  - added 'shortmess' option
  - fixed for redrawing and searching in less-like mode
* Thu Oct 18 2012 pascal.bleser@opensuse.org
- update to 0.7.4: bugfixes
* Fri Mar 30 2012 pascal.bleser@opensuse.org
- update to 0.7.2a: repackaged because of missing files
* Mon Feb 20 2012 puzel@suse.com
- update to 0.7.2
  (see /usr/share/doc/packages/vifm/ChangeLog for details)
- drop vifm-fix_buffer_overflow.patch (fixed upstream)
* Wed Nov 30 2011 pascal.bleser@opensuse.org
- update to 0.7.1
  (see /usr/share/doc/packages/vifm/ChangeLog for details)
* Mon Jun 13 2011 puzel@novell.com
- update to vifm-0.6.1
  - see /usr/share/doc/packages/vifm/ChangeLog for details
- add pkg-config and file-devel to BuildRequires
* Mon Sep 14 2009 puzel@novell.com
- update to vifm-0.5
  * Changed the file size to a human friendly notation.
  * Added ascending and descending sort types.
  * Changed the way symbolic directories are handled.
  * Fixed possible buffer overflow in colorschemes.
  * Fixed transparency in colorschemes.
  * Changed writing to vifmrc file to query user if
    they would like to overwrite a file that has been modified.
  * Added filetype settings for mounting files with fuse-zip.
  * Pauseme script was changed to report errors.
  * Command line input now accepts wide characters and tab completion
    now cycles through all possible matches.
  * ncursesw is now required to build vifm.
* Tue Dec  9 2008 puzel@suse.cz
- fix rpmlint warnings
* Mon Jul 14 2008 puzel@suse.cz
- initial package
